#!/usr/bin/env python
#pylint: skip-file
"""
PnpprojectApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class PnpprojectApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getPnpSiteByRange(self, **kwargs):
        """Retrieves a list of projects

        Args:

            siteName, str: Project Name (required)


            state, str: State of a project.Allowed states are PRE-PROVISIONED,IN_PROGRESS,ERROR,PROVISIONED. (required)


            provisionedOn, str: Provisioned date. (required)


            provisionedBy, str: User who provisioned the project. (required)


            sortBy, str: Sort response based on field (required)


            order, str: Order response in ascending (asc) or descending (des) order (required)


            offset, int: Starting index of the response. Minimum value is 1 (required)


            limit, int: Limit the number of responses. Maximum value supported is 500. Minimum value is 1 (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdSiteListResult
        """

        allParams = ['siteName', 'state', 'provisionedOn', 'provisionedBy', 'sortBy', 'order', 'offset', 'limit', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpSiteByRange" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('siteName' in params):
            queryParams['siteName'] = self.apiClient.toPathValue(params['siteName'])

        if ('state' in params):
            queryParams['state'] = self.apiClient.toPathValue(params['state'])

        if ('provisionedOn' in params):
            queryParams['provisionedOn'] = self.apiClient.toPathValue(params['provisionedOn'])

        if ('provisionedBy' in params):
            queryParams['provisionedBy'] = self.apiClient.toPathValue(params['provisionedBy'])

        if ('sortBy' in params):
            queryParams['sortBy'] = self.apiClient.toPathValue(params['sortBy'])

        if ('order' in params):
            queryParams['order'] = self.apiClient.toPathValue(params['order'])

        if ('offset' in params):
            queryParams['offset'] = self.apiClient.toPathValue(params['offset'])

        if ('limit' in params):
            queryParams['limit'] = self.apiClient.toPathValue(params['limit'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdSiteListResult')
        return responseObject




    def updatePnpSite(self, **kwargs):
        """Updates a project with its ID

        Args:

            project, list[ZtdSite]: PnP project. Site ID is mandatory (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['project', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updatePnpSite" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('project' in params):
            bodyParam = params['project']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def createPnpSite(self, **kwargs):
        """Creates a new project

        Args:

            project, list[ZtdSite]: PnP project. Project name is mandatory. (required)


            source, str: Project ID to clone from. Only the new project name is required in the request body for clone (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['project', 'source', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createPnpSite" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('source' in params):
            queryParams['source'] = self.apiClient.toPathValue(params['source'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('project' in params):
            bodyParam = params['project']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getPnpSiteCount(self, **kwargs):
        """Retrieves a count of projects

        Args:

            siteName, str: Project Name (required)


            state, str: State of a project.Allowed states are PRE_PROVISIONED, IN_PROGRESS, ERROR, PROVISIONED. (required)


            provisionedOn, str: Provisioned date. (required)


            provisionedBy, str: User who provisioned the project. (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: CountResult
        """

        allParams = ['siteName', 'state', 'provisionedOn', 'provisionedBy', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpSiteCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('siteName' in params):
            queryParams['siteName'] = self.apiClient.toPathValue(params['siteName'])

        if ('state' in params):
            queryParams['state'] = self.apiClient.toPathValue(params['state'])

        if ('provisionedOn' in params):
            queryParams['provisionedOn'] = self.apiClient.toPathValue(params['provisionedOn'])

        if ('provisionedBy' in params):
            queryParams['provisionedBy'] = self.apiClient.toPathValue(params['provisionedBy'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def exportPnpSitesAndDevices(self, **kwargs):
        """Retrieves the projects and their associated rules in a file of the given format

        Args:

            format, str: Format of the file. Currently only csv is supported (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: Void
        """

        allParams = ['format', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method exportPnpSitesAndDevices" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/seed-file'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('format' in params):
            queryParams['format'] = self.apiClient.toPathValue(params['format'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Void')
        return responseObject




    def importPnpSitesAndDevices(self, **kwargs):
        """Imports projects and associated rules in bulk

        Args:

            seedFile, file: Seed file (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['seedFile', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method importPnpSitesAndDevices" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/seed-file'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = {}

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'multipart/form-data'




        if ('scope' in params):
            headerParams['scope'] = params['scope']





        if ('seedFile' in params):
            bodyParam['seedFile'] = params['seedFile']




        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getAllPnpBulkImportJobs(self, **kwargs):
        """Retrieves the status of previous import jobs

        Args:

            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdBulkStatusListResult
        """

        allParams = ['scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAllPnpBulkImportJobs" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/seed-file/status'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdBulkStatusListResult')
        return responseObject




    def getPnpBulkStatus(self, **kwargs):
        """Retrieves the status of an import job with its ID

        Args:

            importId, str: Import ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdBulkStatusResult
        """

        allParams = ['importId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpBulkStatus" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/seed-file/{importId}/status'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('importId' in params):
            replacement = str(self.apiClient.toPathValue(params['importId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'importId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdBulkStatusResult')
        return responseObject




    def getPnpBulkReport(self, **kwargs):
        """Retrieves the report of an import job with its ID

        Args:

            importId, str: Import ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: Void
        """

        allParams = ['importId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpBulkReport" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/seed-file/{importId}/status/report'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('importId' in params):
            replacement = str(self.apiClient.toPathValue(params['importId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'importId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Void')
        return responseObject




    def getPnpTemplate(self, **kwargs):
        """Retrieves a template file for an import job

        Args:

            format, str: Format of the file. Currently only csv is supported (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: Void
        """

        allParams = ['format', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpTemplate" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/template-file'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('format' in params):
            queryParams['format'] = self.apiClient.toPathValue(params['format'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Void')
        return responseObject




    def getPnpSiteById(self, **kwargs):
        """Retrieves a project with its ID

        Args:

            projectId, str: Project ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdSiteResult
        """

        allParams = ['projectId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpSiteById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/{projectId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('projectId' in params):
            replacement = str(self.apiClient.toPathValue(params['projectId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'projectId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdSiteResult')
        return responseObject




    def deletePnpSiteByID(self, **kwargs):
        """Deletes a project with its ID

        Args:

            projectId, str: Project ID (required)


            deleteRule, int: Delete project rules (true) or not (false) (required)


            deleteDevice, int: Delete project devices (true) or not (false) (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['projectId', 'deleteRule', 'deleteDevice', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deletePnpSiteByID" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/{projectId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('deleteRule' in params):
            queryParams['deleteRule'] = self.apiClient.toPathValue(params['deleteRule'])

        if ('deleteDevice' in params):
            queryParams['deleteDevice'] = self.apiClient.toPathValue(params['deleteDevice'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('projectId' in params):
            replacement = str(self.apiClient.toPathValue(params['projectId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'projectId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getPnpSiteDevicesBySiteNameAndRange(self, **kwargs):
        """Retrieves a list of devices under a given project

        Args:

            projectId, str: Project ID (required)


            serialNumber, str: Serial number (required)


            productId, str: Product ID (required)


            hostName, str: Host name (required)


            pkiEnabled, str: Device certificate provisioned (true) or not (false) (required)


            state, str: State of device. PENDING, PROVISIONED. Accepts a list of states (required)


            authStatus, str: Authentication status of device: authenticated, error, unsupported (required)


            startLastStateTransitionTime, str: Start of last state transition time (format: yyyy-MM-dd HH:mm:ss) (required)


            endLastStateTransitionTime, str: End of last state transition time (format: yyyy-MM-dd HH:mm:ss) (required)


            sortBy, str: Sort response based on field (required)


            order, str: Order response in ascending (asc) or descending (des) order (required)


            offset, int: Starting index of the response. Minimum value is 1 (required)


            limit, int: Limit the number of responses. Maximum value supported is 500. Minimum value is 1 (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdSiteDeviceListResult
        """

        allParams = ['projectId', 'serialNumber', 'productId', 'hostName', 'pkiEnabled', 'state', 'authStatus', 'startLastStateTransitionTime', 'endLastStateTransitionTime', 'sortBy', 'order', 'offset', 'limit', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpSiteDevicesBySiteNameAndRange" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/{projectId}/device'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('serialNumber' in params):
            queryParams['serialNumber'] = self.apiClient.toPathValue(params['serialNumber'])

        if ('productId' in params):
            queryParams['productId'] = self.apiClient.toPathValue(params['productId'])

        if ('hostName' in params):
            queryParams['hostName'] = self.apiClient.toPathValue(params['hostName'])

        if ('pkiEnabled' in params):
            queryParams['pkiEnabled'] = self.apiClient.toPathValue(params['pkiEnabled'])

        if ('state' in params):
            queryParams['state'] = self.apiClient.toPathValue(params['state'])

        if ('authStatus' in params):
            queryParams['authStatus'] = self.apiClient.toPathValue(params['authStatus'])

        if ('startLastStateTransitionTime' in params):
            queryParams['startLastStateTransitionTime'] = self.apiClient.toPathValue(params['startLastStateTransitionTime'])

        if ('endLastStateTransitionTime' in params):
            queryParams['endLastStateTransitionTime'] = self.apiClient.toPathValue(params['endLastStateTransitionTime'])

        if ('sortBy' in params):
            queryParams['sortBy'] = self.apiClient.toPathValue(params['sortBy'])

        if ('order' in params):
            queryParams['order'] = self.apiClient.toPathValue(params['order'])

        if ('offset' in params):
            queryParams['offset'] = self.apiClient.toPathValue(params['offset'])

        if ('limit' in params):
            queryParams['limit'] = self.apiClient.toPathValue(params['limit'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('projectId' in params):
            replacement = str(self.apiClient.toPathValue(params['projectId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'projectId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdSiteDeviceListResult')
        return responseObject




    def updatePnpSiteDevice(self, **kwargs):
        """Updates a device under a given project with its ID

        Args:

            projectId, str: Project ID (required)


            rule, list[ZtdRule]: PnP rule. Rule ID is mandatory (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['projectId', 'rule', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updatePnpSiteDevice" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/{projectId}/device'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('projectId' in params):
            replacement = str(self.apiClient.toPathValue(params['projectId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'projectId' + '}',
                                                replacement)





        if ('rule' in params):
            bodyParam = params['rule']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def createPnpSiteDevice(self, **kwargs):
        """Creates a new device under a given project

        Args:

            projectId, str: Project ID (required)


            rule, list[ZtdRule]: PnP rule. Host name, Platform ID are mandatory (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['projectId', 'rule', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createPnpSiteDevice" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/{projectId}/device'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('projectId' in params):
            replacement = str(self.apiClient.toPathValue(params['projectId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'projectId' + '}',
                                                replacement)





        if ('rule' in params):
            bodyParam = params['rule']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def downloadPnpBootStrap(self, **kwargs):
        """Retrieves the device bootstrap file under a given project

        Args:

            projectId, str: Project ID (required)


            fileId, str: File ID (required)



        Returns: Void
        """

        allParams = ['projectId', 'fileId']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method downloadPnpBootStrap" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/{projectId}/device-bootstrap/{fileId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('projectId' in params):
            replacement = str(self.apiClient.toPathValue(params['projectId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'projectId' + '}',
                                                replacement)

        if ('fileId' in params):
            replacement = str(self.apiClient.toPathValue(params['fileId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'fileId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'Void')
        return responseObject




    def getPnpSiteDeviceCount(self, **kwargs):
        """Retrieves a count of devices under a given project

        Args:

            projectId, str: Project ID (required)


            serialNumber, str: Serial number (required)


            productId, str: Product ID (required)


            hostName, str: Host name (required)


            pkiEnabled, str: Device certificate provisioned (true) or not (false) (required)


            state, str: State of device. PENDING, PROVISIONED. Accepts a list of states (required)


            authStatus, str: Authentication status of device: authenticated, error, unsupported (required)


            startLastStateTransitionTime, str: Start of last state transition time (format: yyyy-MM-dd HH:mm:ss) (required)


            endLastStateTransitionTime, str: End of last state transition time (format: yyyy-MM-dd HH:mm:ss) (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: CountResult
        """

        allParams = ['projectId', 'serialNumber', 'productId', 'hostName', 'pkiEnabled', 'state', 'authStatus', 'startLastStateTransitionTime', 'endLastStateTransitionTime', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpSiteDeviceCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/{projectId}/device/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('serialNumber' in params):
            queryParams['serialNumber'] = self.apiClient.toPathValue(params['serialNumber'])

        if ('productId' in params):
            queryParams['productId'] = self.apiClient.toPathValue(params['productId'])

        if ('hostName' in params):
            queryParams['hostName'] = self.apiClient.toPathValue(params['hostName'])

        if ('pkiEnabled' in params):
            queryParams['pkiEnabled'] = self.apiClient.toPathValue(params['pkiEnabled'])

        if ('state' in params):
            queryParams['state'] = self.apiClient.toPathValue(params['state'])

        if ('authStatus' in params):
            queryParams['authStatus'] = self.apiClient.toPathValue(params['authStatus'])

        if ('startLastStateTransitionTime' in params):
            queryParams['startLastStateTransitionTime'] = self.apiClient.toPathValue(params['startLastStateTransitionTime'])

        if ('endLastStateTransitionTime' in params):
            queryParams['endLastStateTransitionTime'] = self.apiClient.toPathValue(params['endLastStateTransitionTime'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('projectId' in params):
            replacement = str(self.apiClient.toPathValue(params['projectId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'projectId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def deletePnpSiteDeviceById(self, **kwargs):
        """Deletes a device under a given project with its ID

        Args:

            projectId, str: Project ID (required)


            deviceId, str: Device ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['projectId', 'deviceId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deletePnpSiteDeviceById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-project/{projectId}/device/{deviceId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('projectId' in params):
            replacement = str(self.apiClient.toPathValue(params['projectId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'projectId' + '}',
                                                replacement)

        if ('deviceId' in params):
            replacement = str(self.apiClient.toPathValue(params['deviceId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'deviceId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class LicenseInfoDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually."""


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'id': 'str',


            'deployPending': 'int',


            'evalPeriodLeft': 'str',


            'usageCount': 'int',


            'type': 'str',


            'isCounted': 'bool',


            'validityPeriodRemaining': 'int',


            'attributeInfo': 'object',


            'storeName': 'str',


            'validityPeriod': 'int',


            'storedUsed': 'int',


            'featureVersion': 'str',


            'hostId': 'str',


            'evalPeriodUsed': 'str',


            'totalCount': 'int',


            'usageCountRemaining': 'int',


            'physicalIndex': 'str',


            'isEulaAccepted': 'bool',


            'expiredDate': 'str',


            'description': 'str',


            'status': 'str',


            'isEulaApplicable': 'bool',


            'provisionState': 'int',


            'parentId': 'int',


            'maxUsageCount': 'int',


            'eulaStatus': 'bool',


            'priority': 'str',


            'name': 'str',


            'counted': 'bool',


            'licenseFileCount': 'int',


            'isTechnologyLicense': 'bool',


            'licenseFileName': 'str',


            'licenseIndex': 'int',


            'expiredPeriod': 'int'

        }

        self.attributeMap = {

            'id': 'id',

            'deployPending': 'deployPending',

            'evalPeriodLeft': 'evalPeriodLeft',

            'usageCount': 'usageCount',

            'type': 'type',

            'isCounted': 'isCounted',

            'validityPeriodRemaining': 'validityPeriodRemaining',

            'attributeInfo': 'attributeInfo',

            'storeName': 'storeName',

            'validityPeriod': 'validityPeriod',

            'storedUsed': 'storedUsed',

            'featureVersion': 'featureVersion',

            'hostId': 'hostId',

            'evalPeriodUsed': 'evalPeriodUsed',

            'totalCount': 'totalCount',

            'usageCountRemaining': 'usageCountRemaining',

            'physicalIndex': 'physicalIndex',

            'isEulaAccepted': 'isEulaAccepted',

            'expiredDate': 'expiredDate',

            'description': 'description',

            'status': 'status',

            'isEulaApplicable': 'isEulaApplicable',

            'provisionState': 'provisionState',

            'parentId': 'parentId',

            'maxUsageCount': 'maxUsageCount',

            'eulaStatus': 'eulaStatus',

            'priority': 'priority',

            'name': 'name',

            'counted': 'counted',

            'licenseFileCount': 'licenseFileCount',

            'isTechnologyLicense': 'isTechnologyLicense',

            'licenseFileName': 'licenseFileName',

            'licenseIndex': 'licenseIndex',

            'expiredPeriod': 'expiredPeriod'

        }


        #ID of license

        self.id = None # str

        #Deploy Pending information of license

        self.deployPending = None # int

        #Number of days remaining in the eval period

        self.evalPeriodLeft = None # str

        #Usage count of the license feature

        self.usageCount = None # int

        #License type

        self.type = None # str

        #If the license is counted as part of license usage

        self.isCounted = None # bool

        #Remaining validityPeriod

        self.validityPeriodRemaining = None # int


        self.attributeInfo = None # object

        #Name of the license Store

        self.storeName = None # str

        #Validity period the the license

        self.validityPeriod = None # int

        #License store usage detail

        self.storedUsed = None # int

        #Version of the license feature

        self.featureVersion = None # str

        #Device Id/Name of the license info

        self.hostId = None # str

        #Number of days used in the eval period

        self.evalPeriodUsed = None # str

        #Number of license installed in the device

        self.totalCount = None # int

        #Unused license count

        self.usageCountRemaining = None # int

        #Physical entity index

        self.physicalIndex = None # str

        #If the EULA is accepted

        self.isEulaAccepted = None # bool

        #Expired date of the license

        self.expiredDate = None # str

        #Description about the license

        self.description = None # str

        #Status of the license

        self.status = None # str

        #If the EULA is applicable

        self.isEulaApplicable = None # bool

        #Provision state of the license feature

        self.provisionState = None # int

        #Parent Id of the license

        self.parentId = None # int

        #Maximum usage of the license feature

        self.maxUsageCount = None # int

        #EULA status of the license

        self.eulaStatus = None # bool

        #License priority

        self.priority = None # str

        #Name of the license feature

        self.name = None # str

        #If license feature is counted as part of the license

        self.counted = None # bool

        #Number of license file

        self.licenseFileCount = None # int

        #If the license is technology license or not

        self.isTechnologyLicense = None # bool

        #Name of license file

        self.licenseFileName = None # str

        #Index of the license

        self.licenseIndex = None # int

        #License expired period

        self.expiredPeriod = None # int




#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class FlowDTO(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'id': 'str',


            'protocol': 'str',


            'status': 'str',


            'codec': 'str',


            'sourcePort': 'str',


            'destPort': 'str',


            'flowType': 'str',


            'sourceIP': 'str',


            'destIP': 'str',


            'detailedFlowType': 'str',


            'averageBandwidth': 'str',


            'peakBandwidth': 'str',


            'clientReference': 'str',


            'networkDeviceId': 'str',


            'networkDeviceName': 'str',


            'interfaceId': 'str',


            'interfaceName': 'str',


            'failureReason': 'str'

        }

        self.attributeMap = {

            'id': 'id',

            'protocol': 'protocol',

            'status': 'status',

            'codec': 'codec',

            'sourcePort': 'sourcePort',

            'destPort': 'destPort',

            'flowType': 'flowType',

            'sourceIP': 'sourceIP',

            'destIP': 'destIP',

            'detailedFlowType': 'detailedFlowType',

            'averageBandwidth': 'averageBandwidth',

            'peakBandwidth': 'peakBandwidth',

            'clientReference': 'clientReference',

            'networkDeviceId': 'networkDeviceId',

            'networkDeviceName': 'networkDeviceName',

            'interfaceId': 'interfaceId',

            'interfaceName': 'interfaceName',

            'failureReason': 'failureReason'

        }


        #id

        self.id = None # str

        #protocol

        self.protocol = None # str


        self.status = None # str

        #codec

        self.codec = None # str

        #sourcePort

        self.sourcePort = None # str

        #destPort

        self.destPort = None # str

        #flowType

        self.flowType = None # str

        #sourceIP

        self.sourceIP = None # str

        #destIP

        self.destIP = None # str

        #detailedFlowType (more detailed classification than flowType)

        self.detailedFlowType = None # str

        #averageBandwidth in kbps (min: 0, max: 2147483647 kbps)

        self.averageBandwidth = None # str

        #peakBandwidth in kbps (min: 0, max: 2147483647 kbps)

        self.peakBandwidth = None # str

        #clientReference (can be used by the client as a reference to this resource

        self.clientReference = None # str

        #networkDeviceId

        self.networkDeviceId = None # str

        #networkDeviceName

        self.networkDeviceName = None # str

        #interfaceId

        self.interfaceId = None # str

        #interfaceName

        self.interfaceName = None # str


        self.failureReason = None # str




#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class NetworkDeviceNIO(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'ingressQueueConfig': 'str',


            'authModelId': 'str',


            'duplicateDeviceId': 'str',


            'anchorWlcForAp': 'str',


            'wlcApDeviceStatus': 'str',


            'vendor': 'str',


            'imageName': 'str',


            'type': 'str',


            'id': 'str',


            'location': 'str',


            'hostname': 'str',


            'tag': 'str',


            'serialNumber': 'str',


            'macAddress': 'str',


            'locationName': 'str',


            'lastUpdated': 'str',


            'upTime': 'str',


            'role': 'str',


            'tagCount': 'int',


            'portRange': 'str',


            'softwareVersion': 'str',


            'numUpdates': 'int',


            'avgUpdateFrequency': 'int',


            'bootDateTime': 'DateTime',


            'interfaceCount': 'str',


            'lineCardCount': 'str',


            'lineCardId': 'str',


            'managementIpAddress': 'str',


            'memorySize': 'str',


            'platformId': 'str',


            'reachabilityFailureReason': 'str',


            'reachabilityStatus': 'str',


            'roleSource': 'str',


            'snmpContact': 'str',


            'snmpLocation': 'str',


            'family': 'str',


            'qosStatus': 'str'

        }

        self.attributeMap = {

            'ingressQueueConfig': 'ingressQueueConfig',

            'authModelId': 'authModelId',

            'duplicateDeviceId': 'duplicateDeviceId',

            'anchorWlcForAp': 'anchorWlcForAp',

            'wlcApDeviceStatus': 'wlcApDeviceStatus',

            'vendor': 'vendor',

            'imageName': 'imageName',

            'type': 'type',

            'id': 'id',

            'location': 'location',

            'hostname': 'hostname',

            'tag': 'tag',

            'serialNumber': 'serialNumber',

            'macAddress': 'macAddress',

            'locationName': 'locationName',

            'lastUpdated': 'lastUpdated',

            'upTime': 'upTime',

            'role': 'role',

            'tagCount': 'tagCount',

            'portRange': 'portRange',

            'softwareVersion': 'softwareVersion',

            'numUpdates': 'numUpdates',

            'avgUpdateFrequency': 'avgUpdateFrequency',

            'bootDateTime': 'bootDateTime',

            'interfaceCount': 'interfaceCount',

            'lineCardCount': 'lineCardCount',

            'lineCardId': 'lineCardId',

            'managementIpAddress': 'managementIpAddress',

            'memorySize': 'memorySize',

            'platformId': 'platformId',

            'reachabilityFailureReason': 'reachabilityFailureReason',

            'reachabilityStatus': 'reachabilityStatus',

            'roleSource': 'roleSource',

            'snmpContact': 'snmpContact',

            'snmpLocation': 'snmpLocation',

            'family': 'family',

            'qosStatus': 'qosStatus'

        }


        #Ingress queue config on device

        self.ingressQueueConfig = None # str

        #Authentication model Id on device

        self.authModelId = None # str

        #Identifier of the duplicate ip of the same device discovered

        self.duplicateDeviceId = None # str

        #Connected WLC device for AP

        self.anchorWlcForAp = None # str

        #Collection status of AP devices

        self.wlcApDeviceStatus = None # str

        #Vendor information of the device

        self.vendor = None # str

        #Image details on the device

        self.imageName = None # str

        #Type of device as switch, router, wireless lan controller, accesspoints

        self.type = None # str

        #Unique identifier of network device

        self.id = None # str

        #Location ID that is associated with the device

        self.location = None # str

        #Device name

        self.hostname = None # str

        #Tag ID that is associated with the device

        self.tag = None # str

        #Serial number of device

        self.serialNumber = None # str

        #MAC address of device

        self.macAddress = None # str

        #Name of the associated location

        self.locationName = None # str

        #Time when the network device info last got updated

        self.lastUpdated = None # str

        #Time that shows for how long the device has been up

        self.upTime = None # str

        #Role of device as access, distribution, border router, core

        self.role = None # str

        #Number of tags associated with the device

        self.tagCount = None # int

        #Range of ports on device

        self.portRange = None # str

        #Software version on the device

        self.softwareVersion = None # str

        #Number of time network-device info got updated

        self.numUpdates = None # int

        #Frequency in which interface info gets updated

        self.avgUpdateFrequency = None # int

        #Device boot time

        self.bootDateTime = None # DateTime

        #Number of interfaces on the device

        self.interfaceCount = None # str

        #Number of linecards on the device

        self.lineCardCount = None # str

        #IDs of linecards of the device

        self.lineCardId = None # str

        #IP address of the device

        self.managementIpAddress = None # str

        #Processor memory size

        self.memorySize = None # str

        #Platform ID of device

        self.platformId = None # str

        #Failure reason for unreachable devices

        self.reachabilityFailureReason = None # str

        #Device reachability status as Reachable / Unreachable

        self.reachabilityStatus = None # str

        #Role source as manual / auto

        self.roleSource = None # str

        #SNMP contact on device

        self.snmpContact = None # str

        #SNMP location on device

        self.snmpLocation = None # str

        #Family of device as switch, router, wireless lan controller, accesspoints

        self.family = None # str

        #Qos status on device

        self.qosStatus = None # str




#!/usr/bin/env python
#pylint: skip-file
"""
UserApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class UserApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getUsers(self, **kwargs):
        """getUsers

        Args:

            authSource, str: authSource (required)



        Returns: UserListResult
        """

        allParams = ['authSource']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getUsers" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('authSource' in params):
            queryParams['authSource'] = self.apiClient.toPathValue(params['authSource'])










        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'UserListResult')
        return responseObject




    def updateUser(self, **kwargs):
        """updateUser

        Args:

            user, UserReqRes: user (required)



        Returns: SuccessResult
        """

        allParams = ['user']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('user' in params):
            bodyParam = params['user']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'SuccessResult')
        return responseObject




    def addUser(self, **kwargs):
        """addUser

        Args:

            user, UserReqRes: user (required)



        Returns: SuccessResult
        """

        allParams = ['user']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('user' in params):
            bodyParam = params['user']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'SuccessResult')
        return responseObject




    def getUsersCache(self, **kwargs):
        """getUsersCache

        Args:


        Returns: UserListResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getUsersCache" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/cache'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'UserListResult')
        return responseObject




    def getAutoPassphrase(self, **kwargs):
        """getAutoPassphrase

        Args:


        Returns: AutoPassphraseResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAutoPassphrase" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/passphrase/auto'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'AutoPassphraseResult')
        return responseObject




    def getAutoPassphraseWithSeedPhrase(self, **kwargs):
        """getAutoPassphrase

        Args:

            seedPhrase, str: seedPhrase (required)



        Returns: AutoPassphraseResult
        """

        allParams = ['seedPhrase']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAutoPassphraseWithSeedPhrase" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/passphrase/auto/{seedPhrase}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('seedPhrase' in params):
            replacement = str(self.apiClient.toPathValue(params['seedPhrase']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'seedPhrase' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'AutoPassphraseResult')
        return responseObject




    def getAttemptCount(self, **kwargs):
        """getAttemptCount

        Args:


        Returns: UserLoginInvalidAttemptCountResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAttemptCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/password-policy/invalid-attempt-count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'UserLoginInvalidAttemptCountResult')
        return responseObject




    def updateAttemptCount(self, **kwargs):
        """updateAttemptCount

        Args:

            attemptCount, UserLoginInvalidAttemptCount: attemptCount (required)



        Returns: SuccessResult
        """

        allParams = ['attemptCount']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateAttemptCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/password-policy/invalid-attempt-count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('attemptCount' in params):
            bodyParam = params['attemptCount']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'SuccessResult')
        return responseObject




    def getLockExpiry(self, **kwargs):
        """getLockExpiry

        Args:


        Returns: UserLockExpiryTimeResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getLockExpiry" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/password-policy/lock-expiry-time'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'UserLockExpiryTimeResult')
        return responseObject




    def updateLockExpiryTimeout(self, **kwargs):
        """updateLockExpiryTimeout

        Args:

            expiryTime, UserLockExpiryTime: expiryTime (required)



        Returns: SuccessResult
        """

        allParams = ['expiryTime']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateLockExpiryTimeout" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/password-policy/lock-expiry-time'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('expiryTime' in params):
            bodyParam = params['expiryTime']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'SuccessResult')
        return responseObject




    def updateUserStatus(self, **kwargs):
        """updateUserStatus

        Args:

            userStatus, UserStatus: userStatus (required)



        Returns: SuccessResult
        """

        allParams = ['userStatus']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateUserStatus" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/status'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('userStatus' in params):
            bodyParam = params['userStatus']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'SuccessResult')
        return responseObject




    def getUserStatus(self, **kwargs):
        """getUserStatus

        Args:

            username, str: username (required)



        Returns: UserStatusResult
        """

        allParams = ['username']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getUserStatus" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/status/{username}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('username' in params):
            replacement = str(self.apiClient.toPathValue(params['username']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'username' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'UserStatusResult')
        return responseObject




    def getUser(self, **kwargs):
        """getUser

        Args:

            username, str: username (required)



        Returns: UserResult
        """

        allParams = ['username']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/{username}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('username' in params):
            replacement = str(self.apiClient.toPathValue(params['username']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'username' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'UserResult')
        return responseObject




    def deleteUser(self, **kwargs):
        """deleteUser

        Args:

            username, str: username (required)



        Returns: SuccessResult
        """

        allParams = ['username']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteUser" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/user/{username}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('username' in params):
            replacement = str(self.apiClient.toPathValue(params['username']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'username' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'SuccessResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
CertificatemanagementApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class CertificatemanagementApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getCertificateBriefList(self, **kwargs):
        """getCertificateBriefList

        Args:

        Returns: CertificateBriefListResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getCertificateBriefList" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'












        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CertificateBriefListResult')
        return responseObject




    def importCertificate(self, **kwargs):
        """importCertificate

        Args:


            certFileUpload, file: Specify the name of Certificate file to upload (required)


            pkFileUpload, file: Specify the name of Private Key file to upload (required)


            pkPassword, str: Private Key Passsword (required)



        Returns: TaskIdResult

        """

        allParams = ['certFileUpload', 'pkFileUpload', 'pkPassword']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method importCertificate" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}

        bodyParam = {}

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'multipart/form-data'


        if ('pkPassword' in params):
            queryParams['pkPassword'] = self.apiClient.toPathValue(params['pkPassword'])


        if ('certFileUpload' in params):
            bodyParam['certFileUpload'] = params['certFileUpload']

        if ('pkFileUpload' in params):
            bodyParam['pkFileUpload'] = params['pkFileUpload']




        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)



        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')

        return responseObject




    def importCertificateP12(self, **kwargs):
        """importCertificateP12

        Args:


            p12FileUpload, file: Specify the name of PKCS#12 file to upload (required)


            p12Password, str: P12 Passsword (required)


            pkPassword, str: Private Key Passsword (required)



        Returns: TaskIdResult
        """

        allParams = ['p12FileUpload', 'p12Password', 'pkPassword']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method importCertificateP12" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate-p12'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}

        bodyParam = {}

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'multipart/form-data'


        if ('p12Password' in params):
            queryParams['p12Password'] = self.apiClient.toPathValue(params['p12Password'])

        if ('pkPassword' in params):
            queryParams['pkPassword'] = self.apiClient.toPathValue(params['pkPassword'])







        if ('p12FileUpload' in params):
            bodyParam['p12FileUpload'] = params['p12FileUpload']





        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getCertificateCount(self, **kwargs):
        """getCertificateBriefList

        Args:



        Returns: CountResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getCertificateCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'

        headerParams['Content-Type'] = 'application/json'












        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def getCertificateBrief(self, **kwargs):
        """getCertificateBrief

        Args:


            certificateId, str: Certificate ID (required)



        Returns: CertificateBriefResult
        """

        allParams = ['certificateId']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getCertificateBrief" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate/{certificateId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'







        if ('certificateId' in params):
            replacement = str(self.apiClient.toPathValue(params['certificateId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'certificateId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CertificateBriefResult')
        return responseObject




    def getCertificateBriefListByRange(self, **kwargs):
        """getCertificateBriefList

        Args:


            startIndex, int: Index to start returning records from (required)


            recordsToReturn, int: Number of records to return (required)



        Returns: CertificateBriefListResult
        """

        allParams = ['startIndex', 'recordsToReturn']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getCertificateBriefListByRange" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate/{startIndex}/{recordsToReturn}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'







        if ('startIndex' in params):
            replacement = str(self.apiClient.toPathValue(params['startIndex']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'startIndex' + '}',
                                                replacement)

        if ('recordsToReturn' in params):
            replacement = str(self.apiClient.toPathValue(params['recordsToReturn']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'recordsToReturn' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CertificateBriefListResult')
        return responseObject




    def getProxyCertificate(self, **kwargs):
        """getProxyCertificate

        Args:



        Returns: CertificateBriefResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getProxyCertificate" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/proxy-certificate'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'

        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CertificateBriefResult')
        return responseObject




    def updateProxyCertState(self, **kwargs):
        """updateProxyCertState

        Args:


            certificateProxyStatus, CertificateProxyStatus: certificateProxyStatus (required)




        Returns: TaskIdResult
        """

        allParams = ['certificateProxyStatus']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateProxyCertState" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/proxy-certificate'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'












        if ('certificateProxyStatus' in params):
            bodyParam = params['certificateProxyStatus']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def postProxyCertificate(self, **kwargs):
        """postProxyCertificate

        Args:


            certFileUpload, file: Specify the name of proxy certificate file to upload (required)



        Returns: TaskIdResult
        """

        allParams = ['certFileUpload']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method postProxyCertificate" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/proxy-certificate'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}

        bodyParam = {}

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'multipart/form-data'




        if ('certFileUpload' in params):
            bodyParam['certFileUpload'] = params['certFileUpload']




        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None


        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class HostDTO(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'hostName': 'str',


            'source': 'str',


            'vlanId': 'str',


            'lastUpdated': 'str',


            'avgUpdateFrequency': 'str',


            'connectedAPMacAddress': 'str',


            'connectedAPName': 'str',


            'connectedInterfaceId': 'str',


            'connectedInterfaceName': 'str',


            'connectedNetworkDeviceId': 'str',


            'connectedNetworkDeviceIpAddress': 'str',


            'hostIp': 'str',


            'hostMac': 'str',


            'hostType': 'str',


            'pointOfAttachment': 'str',


            'pointOfPresence': 'str',


            'attributeInfo': 'object',

            'id': 'str'

        }

        self.attributeMap = {

            'hostName': 'hostName',

            'source': 'source',

            'vlanId': 'vlanId',

            'lastUpdated': 'lastUpdated',

            'avgUpdateFrequency': 'avgUpdateFrequency',

            'connectedAPMacAddress': 'connectedAPMacAddress',

            'connectedAPName': 'connectedAPName',

            'connectedInterfaceId': 'connectedInterfaceId',

            'connectedInterfaceName': 'connectedInterfaceName',

            'connectedNetworkDeviceId': 'connectedNetworkDeviceId',

            'connectedNetworkDeviceIpAddress': 'connectedNetworkDeviceIpAddress',

            'hostIp': 'hostIp',

            'hostMac': 'hostMac',

            'hostType': 'hostType',

            'pointOfAttachment': 'pointOfAttachment',

            'pointOfPresence': 'pointOfPresence',

            'attributeInfo': 'attributeInfo',

            'id': 'id'

        }


        #Name of the host

        self.hostName = None # str

        #Source from which the host gets collected. Available option:200 for inventory collection and 300 for trap based data collection

        self.source = None # str

        #Vlan Id of the host

        self.vlanId = None # str

        #Time when the host info last got updated

        self.lastUpdated = None # str

        #Frequency in which host info gets updated

        self.avgUpdateFrequency = None # str

        #Mac address of the AP to which wireless host gets connected

        self.connectedAPMacAddress = None # str

        #Name of the AP to which wireless host gets connected

        self.connectedAPName = None # str

        #Id of the interface to which host gets connected

        self.connectedInterfaceId = None # str

        #Name of the interface to which host gets connected

        self.connectedInterfaceName = None # str

        #Id of the network device to which host gets connected

        self.connectedNetworkDeviceId = None # str

        #Ip address of the network device to which host gets connected

        self.connectedNetworkDeviceIpAddress = None # str

        #Ip address of the host

        self.hostIp = None # str

        #Mac address of the host

        self.hostMac = None # str

        #Type of the host. Available options are: Wired, Wireless

        self.hostType = None # str

        #Id of the Host&#39;s Point of attachment network device (wlc). Based on mobility

        self.pointOfAttachment = None # str

        #Id of the Host&#39;s Point of presence network device (wlc). Based on mobility

        self.pointOfPresence = None # str


        self.attributeInfo = None # object


        self.id = None # str




#!/usr/bin/env python
#pylint: skip-file
"""
V2PolicyApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class V2PolicyApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getPolicyByFilters(self, **kwargs):
        """Retrieves policies based on a given filter

        Args:

            name, str: Retrieve policies for a given name (required)


            contract+name, str: Retrieve policies for a given contract name (required)


            producer+scalableGroupName, str: Retrieve policies for a given producer scalable group name (required)


            consumer+scalableGroupName, str: Retrieve policies for a given consumer scalable group name (required)


            scalableGroupName, str: Retrieve policies for a given scalable group name (used within producer or consumer) (required)


            offset, str: Starting index of the resources (1 based) (required)


            limit, str: Number of resources to return (required)



        Returns: PolicyDTOListResult
        """

        allParams = ['name', 'contract+name', 'producer+scalableGroupName', 'consumer+scalableGroupName', 'scalableGroupName', 'offset', 'limit']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPolicyByFilters" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/policy'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('name' in params):
            queryParams['name'] = self.apiClient.toPathValue(params['name'])

        if ('contract+name' in params):
            queryParams['contract+name'] = self.apiClient.toPathValue(params['contract+name'])

        if ('producer+scalableGroupName' in params):
            queryParams['producer+scalableGroupName'] = self.apiClient.toPathValue(params['producer+scalableGroupName'])

        if ('consumer+scalableGroupName' in params):
            queryParams['consumer+scalableGroupName'] = self.apiClient.toPathValue(params['consumer+scalableGroupName'])

        if ('scalableGroupName' in params):
            queryParams['scalableGroupName'] = self.apiClient.toPathValue(params['scalableGroupName'])

        if ('offset' in params):
            queryParams['offset'] = self.apiClient.toPathValue(params['offset'])

        if ('limit' in params):
            queryParams['limit'] = self.apiClient.toPathValue(params['limit'])










        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PolicyDTOListResult')
        return responseObject




    def update(self, **kwargs):
        """Create Policy(s)

        Args:

            policyDTOs, list[PolicyDTO]: Policy Object(s) (required)



        Returns: TaskIdResult
        """

        allParams = ['policyDTOs']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method update" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/policy'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('policyDTOs' in params):
            bodyParam = params['policyDTOs']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def add(self, **kwargs):
        """Create Policy(s)

        Args:

            policyDTOs, list[PolicyDTO]: Policy Object(s) (required)



        Returns: TaskIdResult
        """

        allParams = ['policyDTOs']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method add" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/policy'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('policyDTOs' in params):
            bodyParam = params['policyDTOs']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getCount(self, **kwargs):
        """Return total count of policies

        Args:


        Returns: CountResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/policy/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def getById(self, **kwargs):
        """Retrieves a policy based on its id

        Args:

            id, str: id (required)



        Returns: PolicyDTOResult
        """

        allParams = ['id']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/policy/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PolicyDTOResult')
        return responseObject




    def delete(self, **kwargs):
        """Deletes a policy by its id

        Args:

            id, str: id (required)



        Returns: TaskIdResult
        """

        allParams = ['id']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method delete" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/policy/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
V2ScalablegroupApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class V2ScalablegroupApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getScalableGroupByFilters(self, **kwargs):
        """Retrieves scalable group based on a given filter

        Args:

            name, str: Retrieve policies for a given name (required)


            offset, str: Starting index of the resources (1 based) (required)


            limit, str: Number of resources to return (required)



        Returns: ScalableGroupListResult
        """

        allParams = ['name', 'offset', 'limit']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getScalableGroupByFilters" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/scalable-group'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('name' in params):
            queryParams['name'] = self.apiClient.toPathValue(params['name'])

        if ('offset' in params):
            queryParams['offset'] = self.apiClient.toPathValue(params['offset'])

        if ('limit' in params):
            queryParams['limit'] = self.apiClient.toPathValue(params['limit'])










        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ScalableGroupListResult')
        return responseObject




    def getCount(self, **kwargs):
        """getCount

        Args:


        Returns: CountResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/scalable-group/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def getEndPointGroupbyId(self, **kwargs):
        """List scalable group based on id

        Args:

            id, str: id (required)



        Returns: ScalableGroupResult
        """

        allParams = ['id']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getEndPointGroupbyId" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/scalable-group/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ScalableGroupResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
LicenseApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class LicenseApi(object):

    def __init__(self, apiClient):
        self.apiClient = apiClient



    def getLicenseInfo(self, **kwargs):
        """Retrieves the license info for a network devices by filters

        Args:

            deviceId, str: Network Device Id (required)


            limit, str: limit (required)


            offset, str: offset (required)


            sortBy, str: sortBy (required)


            order, str: order (required)


            countedList, list[str]: countedList (required)


            deployPendingList, list[str]: deployPendingList (required)


            eulaStatusList, list[str]: eulaStatusList (required)


            evalPeriodLeftList, list[str]: evalPeriodLeftList (required)


            evalPeriodUsedList, list[str]: evalPeriodUsedList (required)


            expiredDateList, list[str]: expiredDateList (required)


            expiredPeriodList, list[str]: expiredPeriodList (required)


            featureVersionList, list[str]: featureVersionList (required)


            hostIdList, list[str]: hostIdList (required)


            isCountedList, list[str]: isCountedList (required)


            isEulaAcceptedList, list[str]: isEulaAcceptedList (required)


            isEulaApplicableList, list[str]: isEulaApplicableList (required)


            isTechnologyLicenseList, list[str]: isTechnologyLicenseList (required)


            licenseFileCountList, list[str]: licenseFileCountList (required)


            licenseFileNameList, list[str]: licenseFileNameList (required)


            licenseIndexList, list[str]: licenseIndexList (required)


            maxUsageCountList, list[str]: maxUsageCountList (required)


            parentIdList, list[str]: parentIdList (required)


            physicalIndexList, list[str]: physicalIndexList (required)


            priorityList, list[str]: priorityList (required)


            provisionStateList, list[str]: provisionStateList (required)


            statusList, list[str]: statusList (required)


            storedUsedList, list[str]: storedUsedList (required)


            storeNameList, list[str]: storeNameList (required)


            totalCountList, list[str]: totalCountList (required)


            licenseTypeList, list[str]: licenseTypeList (required)


            usageCountList, list[str]: usageCountList (required)


            usageCountRemainingList, list[str]: usageCountRemainingList (required)


            validityPeriodList, list[str]: validityPeriodList (required)


            validityPeriodRemainingList, list[str]: validityPeriodRemainingList (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: LicenseInfoListResult
        """

        allParams = ['deviceId', 'limit', 'offset', 'sortBy', 'order', 'countedList', 'deployPendingList', 'eulaStatusList', 'evalPeriodLeftList', 'evalPeriodUsedList', 'expiredDateList', 'expiredPeriodList', 'featureVersionList', 'hostIdList', 'isCountedList', 'isEulaAcceptedList', 'isEulaApplicableList', 'isTechnologyLicenseList', 'licenseFileCountList', 'licenseFileNameList', 'licenseIndexList', 'maxUsageCountList', 'parentIdList', 'physicalIndexList', 'priorityList', 'provisionStateList', 'statusList', 'storedUsedList', 'storeNameList', 'totalCountList', 'licenseTypeList', 'usageCountList', 'usageCountRemainingList', 'validityPeriodList', 'validityPeriodRemainingList', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getLicenseInfo" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/license-info/network-device/{deviceId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('limit' in params):
            queryParams['limit'] = self.apiClient.toPathValue(params['limit'])

        if ('offset' in params):
            queryParams['offset'] = self.apiClient.toPathValue(params['offset'])

        if ('sortBy' in params):
            queryParams['sortBy'] = self.apiClient.toPathValue(params['sortBy'])

        if ('order' in params):
            queryParams['order'] = self.apiClient.toPathValue(params['order'])

        if ('countedList' in params):
            queryParams['countedList'] = self.apiClient.toPathValue(params['countedList'])

        if ('deployPendingList' in params):
            queryParams['deployPendingList'] = self.apiClient.toPathValue(params['deployPendingList'])

        if ('eulaStatusList' in params):
            queryParams['eulaStatusList'] = self.apiClient.toPathValue(params['eulaStatusList'])

        if ('evalPeriodLeftList' in params):
            queryParams['evalPeriodLeftList'] = self.apiClient.toPathValue(params['evalPeriodLeftList'])

        if ('evalPeriodUsedList' in params):
            queryParams['evalPeriodUsedList'] = self.apiClient.toPathValue(params['evalPeriodUsedList'])

        if ('expiredDateList' in params):
            queryParams['expiredDateList'] = self.apiClient.toPathValue(params['expiredDateList'])

        if ('expiredPeriodList' in params):
            queryParams['expiredPeriodList'] = self.apiClient.toPathValue(params['expiredPeriodList'])

        if ('featureVersionList' in params):
            queryParams['featureVersionList'] = self.apiClient.toPathValue(params['featureVersionList'])

        if ('hostIdList' in params):
            queryParams['hostIdList'] = self.apiClient.toPathValue(params['hostIdList'])

        if ('isCountedList' in params):
            queryParams['isCountedList'] = self.apiClient.toPathValue(params['isCountedList'])

        if ('isEulaAcceptedList' in params):
            queryParams['isEulaAcceptedList'] = self.apiClient.toPathValue(params['isEulaAcceptedList'])

        if ('isEulaApplicableList' in params):
            queryParams['isEulaApplicableList'] = self.apiClient.toPathValue(params['isEulaApplicableList'])

        if ('isTechnologyLicenseList' in params):
            queryParams['isTechnologyLicenseList'] = self.apiClient.toPathValue(params['isTechnologyLicenseList'])

        if ('licenseFileCountList' in params):
            queryParams['licenseFileCountList'] = self.apiClient.toPathValue(params['licenseFileCountList'])

        if ('licenseFileNameList' in params):
            queryParams['licenseFileNameList'] = self.apiClient.toPathValue(params['licenseFileNameList'])

        if ('licenseIndexList' in params):
            queryParams['licenseIndexList'] = self.apiClient.toPathValue(params['licenseIndexList'])

        if ('maxUsageCountList' in params):
            queryParams['maxUsageCountList'] = self.apiClient.toPathValue(params['maxUsageCountList'])

        if ('parentIdList' in params):
            queryParams['parentIdList'] = self.apiClient.toPathValue(params['parentIdList'])

        if ('physicalIndexList' in params):
            queryParams['physicalIndexList'] = self.apiClient.toPathValue(params['physicalIndexList'])

        if ('priorityList' in params):
            queryParams['priorityList'] = self.apiClient.toPathValue(params['priorityList'])

        if ('provisionStateList' in params):
            queryParams['provisionStateList'] = self.apiClient.toPathValue(params['provisionStateList'])

        if ('statusList' in params):
            queryParams['statusList'] = self.apiClient.toPathValue(params['statusList'])

        if ('storedUsedList' in params):
            queryParams['storedUsedList'] = self.apiClient.toPathValue(params['storedUsedList'])

        if ('storeNameList' in params):
            queryParams['storeNameList'] = self.apiClient.toPathValue(params['storeNameList'])

        if ('totalCountList' in params):
            queryParams['totalCountList'] = self.apiClient.toPathValue(params['totalCountList'])

        if ('licenseTypeList' in params):
            queryParams['licenseTypeList'] = self.apiClient.toPathValue(params['licenseTypeList'])

        if ('usageCountList' in params):
            queryParams['usageCountList'] = self.apiClient.toPathValue(params['usageCountList'])

        if ('usageCountRemainingList' in params):
            queryParams['usageCountRemainingList'] = self.apiClient.toPathValue(params['usageCountRemainingList'])

        if ('validityPeriodList' in params):
            queryParams['validityPeriodList'] = self.apiClient.toPathValue(params['validityPeriodList'])

        if ('validityPeriodRemainingList' in params):
            queryParams['validityPeriodRemainingList'] = self.apiClient.toPathValue(params['validityPeriodRemainingList'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('deviceId' in params):
            replacement = str(self.apiClient.toPathValue(params['deviceId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'deviceId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'LicenseInfoListResult')
        return responseObject




    def getLicenseInfoCount(self, **kwargs):
        """Retrieves the license info for a network devices by filters

        Args:

            deviceId, str: Network Device Id (required)


            countedList, list[str]: countedList (required)


            deployPendingList, list[str]: deployPendingList (required)


            eulaStatusList, list[str]: eulaStatusList (required)


            evalPeriodLeftList, list[str]: evalPeriodLeftList (required)


            evalPeriodUsedList, list[str]: evalPeriodUsedList (required)


            expiredDateList, list[str]: expiredDateList (required)


            expiredPeriodList, list[str]: expiredPeriodList (required)


            featureVersionList, list[str]: featureVersionList (required)


            hostIdList, list[str]: hostIdList (required)


            isCountedList, list[str]: isCountedList (required)


            isEulaAcceptedList, list[str]: isEulaAcceptedList (required)


            isEulaApplicableList, list[str]: isEulaApplicableList (required)


            isTechnologyLicenseList, list[str]: isTechnologyLicenseList (required)


            licenseFileCountList, list[str]: licenseFileCountList (required)


            licenseFileNameList, list[str]: licenseFileNameList (required)


            licenseIndexList, list[str]: licenseIndexList (required)


            maxUsageCountList, list[str]: maxUsageCountList (required)


            parentIdList, list[str]: parentIdList (required)


            physicalIndexList, list[str]: physicalIndexList (required)


            priorityList, list[str]: priorityList (required)


            provisionStateList, list[str]: provisionStateList (required)


            statusList, list[str]: statusList (required)


            storedUsedList, list[str]: storedUsedList (required)


            storeNameList, list[str]: storeNameList (required)


            totalCountList, list[str]: totalCountList (required)


            licenseTypeList, list[str]: licenseTypeList (required)


            usageCountList, list[str]: usageCountList (required)


            usageCountRemainingList, list[str]: usageCountRemainingList (required)


            validityPeriodList, list[str]: validityPeriodList (required)


            validityPeriodRemainingList, list[str]: validityPeriodRemainingList (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: CountResult
        """

        allParams = ['deviceId', 'countedList', 'deployPendingList', 'eulaStatusList', 'evalPeriodLeftList', 'evalPeriodUsedList', 'expiredDateList', 'expiredPeriodList', 'featureVersionList', 'hostIdList', 'isCountedList', 'isEulaAcceptedList', 'isEulaApplicableList', 'isTechnologyLicenseList', 'licenseFileCountList', 'licenseFileNameList', 'licenseIndexList', 'maxUsageCountList', 'parentIdList', 'physicalIndexList', 'priorityList', 'provisionStateList', 'statusList', 'storedUsedList', 'storeNameList', 'totalCountList', 'licenseTypeList', 'usageCountList', 'usageCountRemainingList', 'validityPeriodList', 'validityPeriodRemainingList', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getLicenseInfoCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/license-info/network-device/{deviceId}/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('countedList' in params):
            queryParams['countedList'] = self.apiClient.toPathValue(params['countedList'])

        if ('deployPendingList' in params):
            queryParams['deployPendingList'] = self.apiClient.toPathValue(params['deployPendingList'])

        if ('eulaStatusList' in params):
            queryParams['eulaStatusList'] = self.apiClient.toPathValue(params['eulaStatusList'])

        if ('evalPeriodLeftList' in params):
            queryParams['evalPeriodLeftList'] = self.apiClient.toPathValue(params['evalPeriodLeftList'])

        if ('evalPeriodUsedList' in params):
            queryParams['evalPeriodUsedList'] = self.apiClient.toPathValue(params['evalPeriodUsedList'])

        if ('expiredDateList' in params):
            queryParams['expiredDateList'] = self.apiClient.toPathValue(params['expiredDateList'])

        if ('expiredPeriodList' in params):
            queryParams['expiredPeriodList'] = self.apiClient.toPathValue(params['expiredPeriodList'])

        if ('featureVersionList' in params):
            queryParams['featureVersionList'] = self.apiClient.toPathValue(params['featureVersionList'])

        if ('hostIdList' in params):
            queryParams['hostIdList'] = self.apiClient.toPathValue(params['hostIdList'])

        if ('isCountedList' in params):
            queryParams['isCountedList'] = self.apiClient.toPathValue(params['isCountedList'])

        if ('isEulaAcceptedList' in params):
            queryParams['isEulaAcceptedList'] = self.apiClient.toPathValue(params['isEulaAcceptedList'])

        if ('isEulaApplicableList' in params):
            queryParams['isEulaApplicableList'] = self.apiClient.toPathValue(params['isEulaApplicableList'])

        if ('isTechnologyLicenseList' in params):
            queryParams['isTechnologyLicenseList'] = self.apiClient.toPathValue(params['isTechnologyLicenseList'])

        if ('licenseFileCountList' in params):
            queryParams['licenseFileCountList'] = self.apiClient.toPathValue(params['licenseFileCountList'])

        if ('licenseFileNameList' in params):
            queryParams['licenseFileNameList'] = self.apiClient.toPathValue(params['licenseFileNameList'])

        if ('licenseIndexList' in params):
            queryParams['licenseIndexList'] = self.apiClient.toPathValue(params['licenseIndexList'])

        if ('maxUsageCountList' in params):
            queryParams['maxUsageCountList'] = self.apiClient.toPathValue(params['maxUsageCountList'])

        if ('parentIdList' in params):
            queryParams['parentIdList'] = self.apiClient.toPathValue(params['parentIdList'])

        if ('physicalIndexList' in params):
            queryParams['physicalIndexList'] = self.apiClient.toPathValue(params['physicalIndexList'])

        if ('priorityList' in params):
            queryParams['priorityList'] = self.apiClient.toPathValue(params['priorityList'])

        if ('provisionStateList' in params):
            queryParams['provisionStateList'] = self.apiClient.toPathValue(params['provisionStateList'])

        if ('statusList' in params):
            queryParams['statusList'] = self.apiClient.toPathValue(params['statusList'])

        if ('storedUsedList' in params):
            queryParams['storedUsedList'] = self.apiClient.toPathValue(params['storedUsedList'])

        if ('storeNameList' in params):
            queryParams['storeNameList'] = self.apiClient.toPathValue(params['storeNameList'])

        if ('totalCountList' in params):
            queryParams['totalCountList'] = self.apiClient.toPathValue(params['totalCountList'])

        if ('licenseTypeList' in params):
            queryParams['licenseTypeList'] = self.apiClient.toPathValue(params['licenseTypeList'])

        if ('usageCountList' in params):
            queryParams['usageCountList'] = self.apiClient.toPathValue(params['usageCountList'])

        if ('usageCountRemainingList' in params):
            queryParams['usageCountRemainingList'] = self.apiClient.toPathValue(params['usageCountRemainingList'])

        if ('validityPeriodList' in params):
            queryParams['validityPeriodList'] = self.apiClient.toPathValue(params['validityPeriodList'])

        if ('validityPeriodRemainingList' in params):
            queryParams['validityPeriodRemainingList'] = self.apiClient.toPathValue(params['validityPeriodRemainingList'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('deviceId' in params):
            replacement = str(self.apiClient.toPathValue(params['deviceId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'deviceId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def getDeviceIdByFilename(self, **kwargs):
        """Retrieves the list of devices with given license filenames

        Args:

            licenseFileName, str: License file name (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: SuccessResultList
        """

        allParams = ['licenseFileName', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getDeviceIdByFilename" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/network-device/license/{licenseFileName}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('licenseFileName' in params):
            replacement = str(self.apiClient.toPathValue(params['licenseFileName']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'licenseFileName' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'SuccessResultList')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
ReachabilityinfoApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class ReachabilityinfoApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getAllNetworkDevicesReachabilityInfo(self, **kwargs):
        """getAllNetworkDevicesReachabilityInfo

        Args:

            scope, str: Authorization Scope for RBAC (required)



        Returns: NetworkDeviceReachabilityInfoNIOListResult
        """

        allParams = ['scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAllNetworkDevicesReachabilityInfo" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'NetworkDeviceReachabilityInfoNIOListResult')
        return responseObject




    def updateNetworkReachabilityInfoById(self, **kwargs):
        """updateNetworkReachabilityInfoById

        Args:

            networkDeviceReachabilityInfoNIO, NetworkDeviceReachabilityInfoNIO: networkDeviceReachabilityInfoNIO (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['networkDeviceReachabilityInfoNIO', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateNetworkReachabilityInfoById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('networkDeviceReachabilityInfoNIO' in params):
            bodyParam = params['networkDeviceReachabilityInfoNIO']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def addNetworkDeviceReachabilityInfo(self, **kwargs):
        """addNetworkDeviceReachabilityInfo

        Args:

            networkDeviceReachabilityInfoNIO, NetworkDeviceReachabilityInfoNIO: networkDeviceReachabilityInfoNIO (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['networkDeviceReachabilityInfoNIO', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addNetworkDeviceReachabilityInfo" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = ''
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('networkDeviceReachabilityInfoNIO' in params):
            bodyParam = params['networkDeviceReachabilityInfoNIO']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def deleteAllNetworkReachabilityInfo(self, **kwargs):
        """deleteAllNetworkReachabilityInfo

        Args:

            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteAllNetworkReachabilityInfo" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getNetworkDevicesReachabilityInfoCount(self, **kwargs):
        """getNetworkDevicesReachabilityInfoCount

        Args:

            scope, str: Authorization Scope for RBAC (required)



        Returns: CountResult
        """

        allParams = ['scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getNetworkDevicesReachabilityInfoCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def getNetworkReachabilityInfoByIpaddress(self, **kwargs):
        """getNetworkReachabilityInfoByIpaddress

        Args:

            ipAddress, str: ipAddress (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: NetworkDeviceReachabilityInfoNIOResult
        """

        allParams = ['ipAddress', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getNetworkReachabilityInfoByIpaddress" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info/ip-address/{ipAddress}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('ipAddress' in params):
            replacement = str(self.apiClient.toPathValue(params['ipAddress']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'ipAddress' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'NetworkDeviceReachabilityInfoNIOResult')
        return responseObject




    def getNetworkReachabilityInfoById(self, **kwargs):
        """getNetworkReachabilityInfoById

        Args:

            networkDeviceId, str: networkDeviceId (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: NetworkDeviceReachabilityInfoNIOResult
        """

        allParams = ['networkDeviceId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getNetworkReachabilityInfoById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info/{networkDeviceId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('networkDeviceId' in params):
            replacement = str(self.apiClient.toPathValue(params['networkDeviceId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'networkDeviceId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'NetworkDeviceReachabilityInfoNIOResult')
        return responseObject




    def deleteNetworkReachabilityInfoById(self, **kwargs):
        """deleteNetworkReachabilityInfoById

        Args:

            networkDeviceId, str: networkDeviceId (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['networkDeviceId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteNetworkReachabilityInfoById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info/{networkDeviceId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('networkDeviceId' in params):
            replacement = str(self.apiClient.toPathValue(params['networkDeviceId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'networkDeviceId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getNetworkDeviceReachabilityInfoByRange(self, **kwargs):
        """getNetworkDeviceReachabilityInfoByRange

        Args:

            startIndex, int: startIndex (required)


            recordsToReturn, int: recordsToReturn (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: NetworkDeviceReachabilityInfoNIOListResult
        """

        allParams = ['startIndex', 'recordsToReturn', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getNetworkDeviceReachabilityInfoByRange" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/reachability-info/{startIndex}/{recordsToReturn}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('startIndex' in params):
            replacement = str(self.apiClient.toPathValue(params['startIndex']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'startIndex' + '}',
                                                replacement)

        if ('recordsToReturn' in params):
            replacement = str(self.apiClient.toPathValue(params['recordsToReturn']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'recordsToReturn' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'NetworkDeviceReachabilityInfoNIOListResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class IpPoolInfo(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'role': 'str',


            'lastUpdateTime': 'int',


            'id': 'str',


            'apicAppName': 'str',


            'nextAddress': 'str',


            'ipPoolName': 'str',


            'creationOrder': 'int',


            'createTime': 'int',


            'ipPool': 'str',


            'startAddress': 'str',


            'endAddress': 'str',


            'dhcpServerIp': 'list[str]',


            'gateway': 'list[str]',


            'interAppOverlap': 'bool',


            'shared': 'bool',


            'usagePercentage': 'int',


            'freeIpCount': 'int',


            'excludeNetworkBroadcastAddress': 'bool',


            'parentId': 'str'

        }

        self.attributeMap = {

            'role': 'role',

            'lastUpdateTime': 'lastUpdateTime',

            'id': 'id',

            'apicAppName': 'apicAppName',

            'nextAddress': 'nextAddress',

            'ipPoolName': 'ipPoolName',

            'creationOrder': 'creationOrder',

            'createTime': 'createTime',

            'ipPool': 'ipPool',

            'startAddress': 'startAddress',

            'endAddress': 'endAddress',

            'dhcpServerIp': 'dhcpServerIp',

            'gateway': 'gateway',

            'interAppOverlap': 'interAppOverlap',

            'shared': 'shared',

            'usagePercentage': 'usagePercentage',

            'freeIpCount': 'freeIpCount',

            'excludeNetworkBroadcastAddress': 'excludeNetworkBroadcastAddress',

            'parentId': 'parentId'

        }


        #Used to group IP Address Pools

        self.role = None # str

        #IP Address Pool last updated time

        self.lastUpdateTime = None # int

        #UUID of IP Address Pool

        self.id = None # str

        #APIC-EM App Name

        self.apicAppName = None # str

        #Next available IP address in IP Address Pool

        self.nextAddress = None # str

        #IP Address Pool name

        self.ipPoolName = None # str

        #Creation order of IP Address Pool

        self.creationOrder = None # int

        #IP Address Pool creation time

        self.createTime = None # int

        #IP subnet in CIDR format

        self.ipPool = None # str

        #First IP address in IP Address Pool

        self.startAddress = None # str

        #Last IP address in IP Address Pool

        self.endAddress = None # str

        #DHCP server hostname or IP address list

        self.dhcpServerIp = None # list[str]

        #Gateway IP address list

        self.gateway = None # list[str]

        #If true then overlapping IP pool is supported between APIC-EM Apps. Default value is false

        self.interAppOverlap = None # bool

        #If true then duplicate/overlapping pool is supported. Default value is false

        self.shared = None # bool

        #Current usage percentage of IP Address Pool

        self.usagePercentage = None # int

        #IP Address Pool free IP count

        self.freeIpCount = None # int

        #If true then network and broadcast IP address will not be used in the usable range. Default value is false

        self.excludeNetworkBroadcastAddress = None # bool

        #Parent IP Address Pool UUID

        self.parentId = None # str



#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class NetworkElement(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'role': 'str',


            'ip': 'str',


            'ingressVirtualInterface': 'Interface',


            'egressVirtualInterface': 'Interface',


            'ingressPhysicalInterface': 'Interface',


            'egressPhysicalInterface': 'Interface',


            'linkInformationSource': 'str',


            'tunnels': 'list[str]',


            'accuracyList': 'list[Accuracy]',


            'deviceStatsCollectionFailureReason': 'str',


            'detailedStatus': 'DetailedStatus',


            'deviceStatistics': 'DeviceStatistics',


            'perfMonStatistics': 'PerfMonitorStatistics',


            'perfMonCollection': 'str',


            'perfMonCollectionFailureReason': 'str',


            'deviceStatsCollection': 'str',


            'name': 'str',


            'id': 'str',


            'type': 'str'

        }

        self.attributeMap = {

            'role': 'role',

            'ip': 'ip',

            'ingressVirtualInterface': 'ingressVirtualInterface',

            'egressVirtualInterface': 'egressVirtualInterface',

            'ingressPhysicalInterface': 'ingressPhysicalInterface',

            'egressPhysicalInterface': 'egressPhysicalInterface',

            'linkInformationSource': 'linkInformationSource',

            'tunnels': 'tunnels',

            'accuracyList': 'accuracyList',

            'deviceStatsCollectionFailureReason': 'deviceStatsCollectionFailureReason',

            'detailedStatus': 'detailedStatus',

            'deviceStatistics': 'deviceStatistics',

            'perfMonStatistics': 'perfMonStatistics',

            'perfMonCollection': 'perfMonCollection',

            'perfMonCollectionFailureReason': 'perfMonCollectionFailureReason',

            'deviceStatsCollection': 'deviceStatsCollection',

            'name': 'name',

            'id': 'id',

            'type': 'type'

        }


        #Role of device in network(can be access,core,distribution or border router)

        self.role = None # str

        #Network Device IP

        self.ip = None # str

        #Ingress virtual interface of the network device

        self.ingressVirtualInterface = None # Interface

        #Egress virtual interface of the network device

        self.egressVirtualInterface = None # Interface

        #Igress physical interface of the network device

        self.ingressPhysicalInterface = None # Interface

        #Egress physical interface of the network device

        self.egressPhysicalInterface = None # Interface

        #The source of the link information to the next hop

        self.linkInformationSource = None # str

        #Tunnels this network element is in

        self.tunnels = None # list[str]


        self.accuracyList = None # list[Accuracy]


        self.deviceStatsCollectionFailureReason = None # str


        self.detailedStatus = None # DetailedStatus


        self.deviceStatistics = None # DeviceStatistics


        self.perfMonStatistics = None # PerfMonitorStatistics

        #A status value from [ INPROGRESS, SUCCESS, FAILED ]

        self.perfMonCollection = None # str


        self.perfMonCollectionFailureReason = None # str

        #A status value from [ INPROGRESS, SUCCESS, FAILED ]

        self.deviceStatsCollection = None # str

        #Network Device name

        self.name = None # str

        #Network Device ID

        self.id = None # str

        #Network Device Type(can be switch,router,wired host or wireless host)

        self.type = None # str




class Contain(object):
    def __init__(self):
        self.swaggerTypes = {
            'id': 'str',
            'name': 'str',
            'contain': 'str'
        }

        self.attributeMap = {
            'id': 'id',
            'name': 'name',
            'contain': 'contain'
        }

        self.id = None
        self.name = None
        self.contain = None